# -*- coding: utf-8 -*-

import os
import json
import logging
from collections import Counter

import pandas as pd

from ydl_ai_recommender.src.utils import get_data_path


class OrderDataManager():
    def __init__(self) -> None:
        self.local_file_dir = get_data_path()
        self.logger = logging.getLogger(__name__)


    def load_raw_data(self):
        df = pd.read_excel(os.path.join(self.local_file_dir, 'all_order_info.xlsx'))
        return df
    

    def make_index(self):
        """
        构建索引
            用户-咨询师 索引
            top50 咨询师列表 用于冷启动
        """
        df = self.load_raw_data()
        self.logger.info('加载数据完成，共加载 %s 条数据', len(df))

        user_order = {}
        for index, row in df.iterrows():
            uid, supplier_id = row['uid'], row['supplier_id']
        
            if uid not in user_order:
                user_order[uid] = {}
            if supplier_id not in user_order[uid]:
                user_order[uid][supplier_id] = []
            user_order[uid][supplier_id].append([row['price'], row['update_time']])
        
        index = {}
        for uid, orders in user_order.items():
            supplier_values = []
            for supplier_id, infos in orders.items():
                # 订单越多排序约靠前，相同数量订单，最新订单约晚越靠前
                value = len(infos)
                latest_time = max([info[1] for info in infos])
                supplier_values.append([supplier_id, value, latest_time])
            
            index[uid] = sorted(supplier_values, key=lambda x: (x[1], x[2]), reverse=True)
        
        with open(os.path.join(self.local_file_dir, 'user_doctor_index.json'), 'w', encoding='utf-8') as f:
            json.dump(index, f, ensure_ascii=False)
        
        # 订单最多的咨询师

        supplier_cnter = Counter(df['supplier_id'])
        top50_supplier = []
        for key, _ in supplier_cnter.most_common(50):
            top50_supplier.append(str(key))
        with open(os.path.join(self.local_file_dir, 'top50_supplier.txt'), 'w', encoding='utf-8') as f:
            f.write('\n'.join(top50_supplier))


if __name__ == '__main__':
    manager = OrderDataManager()
    print(manager.make_index())