# -*- coding: utf-8 -*-

import os
import json
import logging

import pandas as pd

from ydl_ai_recommender.src.utils import get_data_path
from ydl_ai_recommender.src.core.profile import profile_converters


class ProfileManager():
    """
    订单用户画像数据管理
    """

    def __init__(self) -> None:
        self.local_file_dir = get_data_path()
        self.profile_file_path = os.path.join(self.local_file_dir, 'all_profile.json')
        self.logger = logging.getLogger(__name__)


    def _load_profile_data(self):
        return pd.read_excel(os.path.join(self.local_file_dir, 'all_profile.xlsx'))
        # with open(self.profile_file_path, 'r', encoding='utf-8') as f:
        #     return json.load(f)


    def profile_to_embedding(self, profile):
        """
        将用户画像信息转换为向量
        """
        embedding = []
        for [name, converter] in profile_converters:
            embedding.extend(converter.convert(profile[name]))
        return embedding


    def make_embeddings(self):
        user_profiles = self._load_profile_data()
        self.logger.info('订单用户画像数据加载完成，共加载 %s 条', len(user_profiles))
        user_ids, embeddings = [], []
        self.logger.info('开始构建订单用户的用户画像向量')
        for _, profile in user_profiles.iterrows():
            user_ids.append(str(profile['uid']))
            embeddings.append(self.profile_to_embedding(profile))
        
        self.logger.info('用户画像向量构建完成，共构建 %s 用户', len(user_ids))

        with open(os.path.join(self.local_file_dir, 'user_embeddings_ids.txt'), 'w', encoding='utf-8') as f:
            f.write('\n'.join(user_ids))

        with open(os.path.join(self.local_file_dir, 'user_embeddings.json'), 'w', encoding='utf-8') as f:
            json.dump(embeddings, f, ensure_ascii=False)

        return embeddings


    def make_virtual_embedding(self):
        user_ids = []
        embeddings = []



if __name__ == '__main__':
    manager = ProfileManager()
    manager.make_embeddings()
    # manager.update_local_data()
    # print(manager.make_index())